==> mercury-0.1.6.tar.gz: lib/src/event_dispatcher.dart <==
part of mercury;

/// A system to dispatch and handle events.
class EventDispatcher {
  Session _session;

  /// Handles an incoming event from Discord.
  Future handleEvent(String eventName, dynamic data, bool isJsonObject) async {
    switch (eventName) {
      case 'READY':
        for (var guild in data['guilds']) {
          bool aval = true;
          if (guild['unavailable'] != null && guild['unavailable'] == true)
            aval = false;
          var guildModel = new Guild(_session);
          await guildModel._update(guild);
          _session.guilds.set(guildModel);
        }
        _readyController.add(null);
        break;
      case 'MESSAGE_CREATE':
        var messageModel = new Message(_session);
        await messageModel._update(data);
        _messageCreateController.add(messageModel);
        break;
      case 'MESSAGE_UPDATE':
        var channel = _session.getChannel(data['channel_id']).value;
        var channel1 = (channel as Messageable);
        var message = channel1.messages.get(data['id']).value;
        await message._update(data);
        _messageUpdateController.add(message);
        break;
      case 'MESSAGE_DELETE':
        var channel = _session.getChannel(data['channel_id']);
        var channel1 = (channel.value as Messageable);
        channel1.messages.remove(data['id']);
        _messageDeleteController.add(data['id']);
        break;
      case 'MESSAGE_DELETE_BULK':
        var channel = _session.getChannel(data['channel_id']);
        var channel1 = (channel as Messageable);
        for (var id in data['ids']) {
          channel1.messages.remove(id);
          _messageDeleteController.add(id);
        }
        break;
      case 'CHANNEL_UPDATE':
        var channelModel = _session.getChannel(data['id']);
        await channelModel.value._update(data);
        channelModel.set(channelModel.value);
        _channelUpdateController.add(channelModel.value);
        break;
      case 'CHANNEL_CREATE':
        var channelModel = ChannelBase.createFromJson(data, _session);
        await channelModel._update(data);
        if (data['guild_id'] != null) {
          // Guild channel
          var guildChan = (channelModel as GuildChannel);
          guildChan.guild = _session.getGuild(data['guild_id']).value;
          guildChan.guild.channels.set(guildChan);
        }
        _channelCreateController.add(channelModel);
        break;
      case 'GUILD_CREATE':
        if (_session.guilds.containsId(data['id'])) {
          var guild = _session.guilds.get(data['id']);
          var gv = guild.value;
          await gv._update(data);
          _session.guilds.set(gv);
        } else {
          var guild = new Guild(_session);
          await guild._update(data);
          _session.guilds.set(guild);
          _guildCreateController.add(guild);
        }
        break;
      case 'GUILD_UPDATE':
        var guildModel = _session.getGuild(data['id']);
        await guildModel.value._update(data);
        guildModel.set(guildModel.value);
        _guildUpdateController.add(guildModel);
        break;
      default:
        break;
    }
  }

  StreamController _messageCreateController = new StreamController.broadcast();
  Stream<Message> messageCreate = null;

  StreamController _messageUpdateController = new StreamController.broadcast();
  Stream<Message> messageUpdate = null;

  StreamController _messageDeleteController = new StreamController.broadcast();
  Stream<String> messageDelete = null;

  StreamController _readyController = new StreamController.broadcast();
  Stream<Null> ready = null;

  StreamController _channelUpdateController = new StreamController.broadcast();
  Stream<ChannelBase> channelUpdate = null;

  StreamController _channelCreateController = new StreamController.broadcast();
  Stream<ChannelBase> channelCreate = null;

  StreamController _guildCreateController = new StreamController.broadcast();
  Stream<Guild> guildCreate = null;

  StreamController _guildUpdateController = new StreamController.broadcast();
  Stream<Guild> guildUpdate = null;

  EventDispatcher(this._session) {
    messageCreate = _messageCreateController.stream;
    messageUpdate = _messageUpdateController.stream;
    messageDelete = _messageDeleteController.stream;
    ready = _readyController.stream;
    channelUpdate = _channelUpdateController.stream;
    channelCreate = _channelCreateController.stream;
    guildCreate = _guildCreateController.stream;
    guildUpdate = _guildUpdateController.stream;
  }
}

==> mercury-0.2.0.tar.gz: lib/src/event_dispatcher.dart <==
part of mercury;

/// A system to dispatch and handle events.
class EventDispatcher {
  Session _session;

  /// Handles an incoming event from Discord.
  Future handleEvent(String eventName, dynamic data, bool isJsonObject) async {
    switch (eventName) {
      case 'READY':
        for (var guild in data['guilds']) {
          bool aval = true;
          if (guild['unavailable'] != null && guild['unavailable'] == true)
            aval = false;
          var guildModel = new Guild(_session);
          await guildModel._update(guild);
          _session.guilds.set(guildModel);
        }
        _readyController.add(null);
        break;
      case 'MESSAGE_CREATE':
        var messageModel = new Message(_session);
        await messageModel._update(data);
        _messageCreateController.add(messageModel);
        break;
      case 'MESSAGE_UPDATE':
        var channel = _session.getCachedChannel(data['channel_id']).value;
        var channel1 = (channel as Messageable);
        var message = channel1.messages.get(data['id']).value;
        await message._update(data);
        _messageUpdateController.add(message);
        break;
      case 'MESSAGE_DELETE':
        var channel = _session.getCachedChannel(data['channel_id']);
        var channel1 = (channel.value as Messageable);
        channel1.messages.remove(data['id']);
        _messageDeleteController.add(data['id']);
        break;
      case 'MESSAGE_DELETE_BULK':
        var channel = _session.getCachedChannel(data['channel_id']);
        var channel1 = (channel as Messageable);
        for (var id in data['ids']) {
          channel1.messages.remove(id);
          _messageDeleteController.add(id);
        }
        break;
      case 'CHANNEL_UPDATE':
        var channelModel = _session.getCachedChannel(data['id']);
        await channelModel.value._update(data);
        channelModel.set(channelModel.value);
        _channelUpdateController.add(channelModel.value);
        break;
      case 'CHANNEL_CREATE':
        var channelModel = ChannelBase.createFromJson(data, _session);
        await channelModel._update(data);
        if (data['guild_id'] != null) {
          // Guild channel
          var guildChan = (channelModel as GuildChannel);
          guildChan.guild = _session.getCachedGuild(data['guild_id']).value;
          guildChan.guild.channels.set(guildChan);
        }
        _channelCreateController.add(channelModel);
        break;
      case 'GUILD_CREATE':
        if (_session.guilds.containsId(data['id'])) {
          var guild = _session.guilds.get(data['id']);
          var gv = guild.value;
          await gv._update(data);
          _session.guilds.set(gv);
        } else {
          var guild = new Guild(_session);
          await guild._update(data);
          _session.guilds.set(guild);
          _guildCreateController.add(guild);
        }
        break;
      case 'GUILD_UPDATE':
        var guildModel = _session.getCachedGuild(data['id']);
        await guildModel.value._update(data);
        guildModel.set(guildModel.value);
        _guildUpdateController.add(guildModel);
        break;
      default:
        break;
    }
  }

  StreamController _messageCreateController = new StreamController.broadcast();
  Stream<Message> messageCreate = null;

  StreamController _messageUpdateController = new StreamController.broadcast();
  Stream<Message> messageUpdate = null;

  StreamController _messageDeleteController = new StreamController.broadcast();
  Stream<String> messageDelete = null;

  StreamController _readyController = new StreamController.broadcast();
  Stream<Null> ready = null;

  StreamController _channelUpdateController = new StreamController.broadcast();
  Stream<ChannelBase> channelUpdate = null;

  StreamController _channelCreateController = new StreamController.broadcast();
  Stream<ChannelBase> channelCreate = null;

  StreamController _guildCreateController = new StreamController.broadcast();
  Stream<Guild> guildCreate = null;

  StreamController _guildUpdateController = new StreamController.broadcast();
  Stream<Guild> guildUpdate = null;

  EventDispatcher(this._session) {
    messageCreate = _messageCreateController.stream;
    messageUpdate = _messageUpdateController.stream;
    messageDelete = _messageDeleteController.stream;
    ready = _readyController.stream;
    channelUpdate = _channelUpdateController.stream;
    channelCreate = _channelCreateController.stream;
    guildCreate = _guildCreateController.stream;
    guildUpdate = _guildUpdateController.stream;
  }
}
